==> drd-8.x-3.4.tar.gz: drd/src/Entities.php <==
<?php

namespace Drupal\drd;

use Drupal\Core\Entity\Entity;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\drd\Entity\Core;
use Drupal\drd\Entity\Domain;
use Drupal\drd\Entity\Host;

/**
 * Query for DRD entities.
 */
class Entities implements EntitiesInterface {

  /** @var EntityTypeManagerInterface */
  protected $entityTypeManager;

  /** @var string */
  protected $type;

  /** @var array */
  protected $properties = [];

  /** @var int */
  protected $hostId;

  /** @var int */
  protected $coreId;

  /** @var int */
  protected $domainId;

  /**
   * @param EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * @inheritDoc
   */
  public function setHostId($id) {
    $this->hostId = $id;
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function setCoreId($id) {
    $this->coreId = $id;
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function setDomainId($id) {
    $this->domainId = $id;
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function hosts() {
    $this->type = 'host';
    $this->properties = [
      'status' => 1,
    ];
    if ($this->domainId) {
      if ($domain = Domain::load($this->domainId)) {
        $this->coreId = $domain->getCore()->id();
      }
      else {
        return $this->none();
      }
    }
    if ($this->coreId) {
      if ($core = Core::load($this->coreId)) {
        $this->hostId = $core->getHost()->id();
      }
      else {
        return $this->none();
      }
    }
    if ($this->hostId) {
      return $this->entities($this->hostId);
    }
    return $this->entities();
  }

  /**
   * @inheritDoc
   */
  public function cores() {
    $this->type = 'core';
    $this->properties = [
      'status' => 1,
    ];
    if ($this->hostId) {
      $this->properties['host'] = $this->hostId;
    }
    else {
      if ($this->domainId) {
        if ($domain = Domain::load($this->domainId)) {
          $this->coreId = $domain->getCore()->id();
        }
        else {
          return $this->none();
        }
      }
      if ($this->coreId) {
        return $this->entities($this->coreId);
      }
    }
    return $this->entities();
  }

  /**
   * @inheritDoc
   */
  public function domains() {
    $this->type = 'domain';
    $this->properties = [
      'status' => 1,
      'installed' => 1,
    ];
    if ($this->hostId) {
      if ($host = Host::load($this->hostId)) {
        array_walk($host->getCores(), function(Core $core) {
          $this->properties['core'][] = $core->id();
        });
      }
      else {
        return $this->none();
      }
    }
    elseif ($this->coreId) {
      $this->properties['core'] = $this->coreId;
    }
    elseif ($this->domainId) {
      return $this->entities($this->domainId);
    }
    return $this->entities();
  }

  /**
   * Nothing found, output a message and return FALSE.
   *
   * @return bool
   */
  protected function none() {
    drupal_set_message('No ' . $this->type . ' found!', 'error');
    return FALSE;
  }

  /**
   * @param $id
   *
   * @return Entity[]
   */
  protected function oneEntity($id) {
    $entity = $this->entityTypeManager
      ->getStorage('drd_' . $this->type)
      ->load($id);
    return empty($entity) ? [] : [$entity];

  }

  /**
   * @param $id
   *
   * @return bool|Entity[]
   */
  protected function entities($id = NULL) {
    $entities = isset($id) ? $this->oneEntity($id) :
      $this->entityTypeManager
        ->getStorage('drd_' . $this->type)
        ->loadByProperties($this->properties);

    if (empty($entities)) {
      return $this->none();
    }

    return $entities;
  }

}

==> drd-8.x-3.10.tar.gz: drd/src/Entities.php <==
<?php

namespace Drupal\drd;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\drd\Entity\Core;
use Drupal\drd\Entity\Domain;
use Drupal\drd\Entity\Host;

/**
 * Query for DRD entities.
 */
class Entities implements EntitiesInterface {

  /** @var \Drupal\Core\Entity\EntityTypeManagerInterface */
  protected $entityTypeManager;

  /** @var string */
  protected $type;

  /** @var array */
  protected $properties = [];

  /** @var int */
  protected $hostId;

  /** @var int */
  protected $coreId;

  /** @var int */
  protected $domainId;

  /**
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * @inheritDoc
   */
  public function setHostId($id) {
    $this->hostId = $id;
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function setCoreId($id) {
    $this->coreId = $id;
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function setDomainId($id) {
    $this->domainId = $id;
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function hosts() {
    $this->type = 'host';
    $this->properties = [
      'status' => 1,
    ];
    if ($this->domainId) {
      if ($domain = Domain::load($this->domainId)) {
        $this->coreId = $domain->getCore()->id();
      }
      else {
        return $this->none();
      }
    }
    if ($this->coreId) {
      if ($core = Core::load($this->coreId)) {
        $this->hostId = $core->getHost()->id();
      }
      else {
        return $this->none();
      }
    }
    if ($this->hostId) {
      return $this->entities($this->hostId);
    }
    return $this->entities();
  }

  /**
   * @inheritDoc
   */
  public function cores() {
    $this->type = 'core';
    $this->properties = [
      'status' => 1,
    ];
    if ($this->hostId) {
      $this->properties['host'] = $this->hostId;
    }
    else {
      if ($this->domainId) {
        if ($domain = Domain::load($this->domainId)) {
          $this->coreId = $domain->getCore()->id();
        }
        else {
          return $this->none();
        }
      }
      if ($this->coreId) {
        return $this->entities($this->coreId);
      }
    }
    return $this->entities();
  }

  /**
   * @inheritDoc
   */
  public function domains() {
    $this->type = 'domain';
    $this->properties = [
      'status' => 1,
      'installed' => 1,
    ];
    if ($this->hostId) {
      if ($host = Host::load($this->hostId)) {
        array_walk($host->getCores(), function(Core $core) {
          $this->properties['core'][] = $core->id();
        });
      }
      else {
        return $this->none();
      }
    }
    elseif ($this->coreId) {
      $this->properties['core'] = $this->coreId;
    }
    elseif ($this->domainId) {
      return $this->entities($this->domainId);
    }
    return $this->entities();
  }

  /**
   * Nothing found, output a message and return FALSE.
   *
   * @return bool
   */
  protected function none() {
    drupal_set_message('No ' . $this->type . ' found!', 'error');
    return FALSE;
  }

  /**
   * @param $id
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   */
  protected function oneEntity($id) {
    $entity = $this->entityTypeManager
      ->getStorage('drd_' . $this->type)
      ->load($id);
    return empty($entity) ? [] : [$entity];

  }

  /**
   * @param $id
   *
   * @return bool|\Drupal\Core\Entity\EntityInterface[]
   */
  protected function entities($id = NULL) {
    $entities = isset($id) ? $this->oneEntity($id) :
      $this->entityTypeManager
        ->getStorage('drd_' . $this->type)
        ->loadByProperties($this->properties);

    if (empty($entities)) {
      return $this->none();
    }

    return $entities;
  }

}
